# A-DAG-IO Framework

[![GitHub release](https://img.shields.io/github/release/fugue-project/adagio.svg)](https://GitHub.com/fugue-project/adagio)
[![PyPI pyversions](https://img.shields.io/pypi/pyversions/adagio.svg)](https://pypi.python.org/pypi/adagio/)
[![PyPI license](https://img.shields.io/pypi/l/adagio.svg)](https://pypi.python.org/pypi/adagio/)
[![PyPI version](https://badge.fury.io/py/adagio.svg)](https://pypi.python.org/pypi/adagio/)
[![codecov](https://codecov.io/gh/fugue-project/adagio/branch/master/graph/badge.svg?token=P82AEINHFY)](https://codecov.io/gh/fugue-project/adagio)

[Join Fugue-Project on Slack](https://join.slack.com/t/fugue-project/shared_invite/zt-he6tcazr-OCkj2GEv~J9UYoZT3FPM4g)

A Dag IO framework for [Fugue projects](https://github.com/fugue-project)

## Installation

```
pip install adagio
```
